==> packageinstaller-pkglist-libre_0.1.3.tar.xz: packageinstaller-pkglist-libre/obsidan-icon-theme.pm <==
<?xml version="1.0"?>
<app>

<category>
Icons
</category>

<name>  
Obsidian Icon Theme
</name>

<description>  
   <am>an updated/refreshed Faenza-ish icon theme with many colour choices</am>
   <ar>an updated/refreshed Faenza-ish icon theme with many colour choices</ar>
   <bg>an updated/refreshed Faenza-ish icon theme with many colour choices</bg>
   <bn>an updated/refreshed Faenza-ish icon theme with many colour choices</bn>
   <ca>tema de icones actualitzat tipus Faenza amb moltes opcions de color</ca>
   <cs>an updated/refreshed Faenza-ish icon theme with many colour choices</cs>
   <da>et opdateret/genopfrisket Faenza-ish-ikontema med mange valg af farver</da>
   <de>Ein aktualisiertes/erfrischtes Faenza-ähnliches Icon-Thema mit vielen Farbvarianten</de>
   <el>ένα ενημερωμένο/ανανεωμένο θέμα του Faenza με πολλές επιλογές χρωμάτων</el>
   <en>an updated/refreshed Faenza-ish icon theme with many colour choices</en>
   <es>Tema de íconos estilo Faenza reelaborados y con múltiples colores a elección.</es>
   <et>an updated/refreshed Faenza-ish icon theme with many colour choices</et>
   <eu>an updated/refreshed Faenza-ish icon theme with many colour choices</eu>
   <fa>an updated/refreshed Faenza-ish icon theme with many colour choices</fa>
   <fil_PH>an updated/refreshed Faenza-ish icon theme with many colour choices</fil_PH>
   <fi>an updated/refreshed Faenza-ish icon theme with many colour choices</fi>
   <fr>Un thème d'icônes de type Faenza remis au goût du jour, avec plusieurs choix de couleurs</fr>
   <he_IL>an updated/refreshed Faenza-ish icon theme with many colour choices</he_IL>
   <hi>an updated/refreshed Faenza-ish icon theme with many colour choices</hi>
   <hr>an updated/refreshed Faenza-ish icon theme with many colour choices</hr>
   <hu>an updated/refreshed Faenza-ish icon theme with many colour choices</hu>
   <id>an updated/refreshed Faenza-ish icon theme with many colour choices</id>
   <is>an updated/refreshed Faenza-ish icon theme with many colour choices</is>
   <it>un tema di icone basato sul tema Faenza rivisto/aggiornato con molte scelte di colore</it>
   <ja_JP>an updated/refreshed Faenza-ish icon theme with many colour choices</ja_JP>
   <ja>an updated/refreshed Faenza-ish icon theme with many colour choices</ja>
   <kk>an updated/refreshed Faenza-ish icon theme with many colour choices</kk>
   <ko>an updated/refreshed Faenza-ish icon theme with many colour choices</ko>
   <lt>an updated/refreshed Faenza-ish icon theme with many colour choices</lt>
   <mk>an updated/refreshed Faenza-ish icon theme with many colour choices</mk>
   <mr>an updated/refreshed Faenza-ish icon theme with many colour choices</mr>
   <nb>an updated/refreshed Faenza-ish icon theme with many colour choices</nb>
   <nl>een geüpdatet/verfrist icoonthema van Faenza-ish met vele kleurkeuzes</nl>
   <pl>zaktualizowany/odświeżony motyw ikon Faenza z wieloma opcjami kolorów</pl>
   <pt_BR>Tema de ícones ao estilo Faenza com muitas opções de cores, actualizado/refrescado</pt_BR>
   <pt>Tema de ícones ao estilo Faenza com muitas opções de cores, actualizado/refrescado</pt>
   <ro>an updated/refreshed Faenza-ish icon theme with many colour choices</ro>
   <ru>Обновленная тема в стиле Faenza с большим выбором цветов</ru>
   <sk>an updated/refreshed Faenza-ish icon theme with many colour choices</sk>
   <sl>Posodboljena in osvežena Faenzajevska predloga ikon z mnogobarvnim izborom</sl>
   <sq>an updated/refreshed Faenza-ish icon theme with many colour choices</sq>
   <sr>an updated/refreshed Faenza-ish icon theme with many colour choices</sr>
   <sv>ett uppdaterat/förbättrat Faenza-aktigt ikontema med många färgval</sv>
   <tr>an updated/refreshed Faenza-ish icon theme with many colour choices</tr>
   <uk>оновлена тема піктограм Faenza з великим вибором кольорів</uk>
   <vi>an updated/refreshed Faenza-ish icon theme with many colour choices</vi>
   <zh_CN>an updated/refreshed Faenza-ish icon theme with many colour choices</zh_CN>
   <zh_TW>an updated/refreshed Faenza-ish icon theme with many colour choices</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
obsidian-icon-theme
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
obsidian-icon-theme
</uninstall_package_names>
</app>

==> packageinstaller-pkglist-libre_0.1.6.tar.xz: packageinstaller-pkglist-libre/obsidan-icon-theme.pm <==
<?xml version="1.0"?>
<app>

<category>
Icons
</category>

<name>
Obsidian Icon Theme
</name>

<description>
   <am>an updated/refreshed Faenza-ish icon theme with many colour choices</am>
   <ar>an updated/refreshed Faenza-ish icon theme with many colour choices</ar>
   <be>an updated/refreshed Faenza-ish icon theme with many colour choices</be>
   <bg>an updated/refreshed Faenza-ish icon theme with many colour choices</bg>
   <bn>an updated/refreshed Faenza-ish icon theme with many colour choices</bn>
   <ca>tema de icones actualitzat tipus Faenza amb moltes opcions de color</ca>
   <cs>an updated/refreshed Faenza-ish icon theme with many colour choices</cs>
   <da>et opdateret/genopfrisket Faenza-ish-ikontema med mange valg af farver</da>
   <de>Ein aktualisiertes/erfrischtes Faenza-ähnliches Icon-Thema mit vielen Farbvarianten</de>
   <el>Ενημερωμένο/ανανεωμένο θέμα του Faenza με πολλές επιλογές χρωμάτων</el>
   <en>an updated/refreshed Faenza-ish icon theme with many colour choices</en>
   <es_ES>Tema de íconos estilo Faenza reelaborados y con múltiples colores a elección.</es_ES>
   <es>Tema de íconos estilo Faenza reelaborados y con múltiples colores a elección.</es>
   <et>an updated/refreshed Faenza-ish icon theme with many colour choices</et>
   <eu>an updated/refreshed Faenza-ish icon theme with many colour choices</eu>
   <fa>an updated/refreshed Faenza-ish icon theme with many colour choices</fa>
   <fil_PH>an updated/refreshed Faenza-ish icon theme with many colour choices</fil_PH>
   <fi>päivitetty/virkistetty Faenza:n kaltainen kuvaketeema monine värivaihtoehtoineen</fi>
   <fr_BE>an updated/refreshed Faenza-ish icon theme with many colour choices</fr_BE>
   <fr>Un thème d'icônes de type Faenza remis au goût du jour, avec plusieurs choix de couleurs</fr>
   <gl_ES>Tema de iconas ao estilo Faenza con moitas opcións de cores, actualizado/refrescado</gl_ES>
   <he_IL>an updated/refreshed Faenza-ish icon theme with many colour choices</he_IL>
   <hi>an updated/refreshed Faenza-ish icon theme with many colour choices</hi>
   <hr>an updated/refreshed Faenza-ish icon theme with many colour choices</hr>
   <hu>an updated/refreshed Faenza-ish icon theme with many colour choices</hu>
   <id>an updated/refreshed Faenza-ish icon theme with many colour choices</id>
   <is>an updated/refreshed Faenza-ish icon theme with many colour choices</is>
   <it>un tema di icone basato sul tema Faenza rivisto/aggiornato con molte scelte di colore</it>
   <ja>多くの色の選択肢を持つ、更新/リフレッシュされた Faenza風のアイコンテーマ</ja>
   <kk>an updated/refreshed Faenza-ish icon theme with many colour choices</kk>
   <ko>an updated/refreshed Faenza-ish icon theme with many colour choices</ko>
   <lt>an updated/refreshed Faenza-ish icon theme with many colour choices</lt>
   <mk>an updated/refreshed Faenza-ish icon theme with many colour choices</mk>
   <mr>an updated/refreshed Faenza-ish icon theme with many colour choices</mr>
   <nb_NO>an updated/refreshed Faenza-ish icon theme with many colour choices</nb_NO>
   <nb>et oppdatert Faenza-aktig ikontema med mange fargevalg</nb>
   <nl_BE>an updated/refreshed Faenza-ish icon theme with many colour choices</nl_BE>
   <nl>een geüpdatet/verfrist icoonthema van Faenza-ish met vele kleurkeuzes</nl>
   <pl>zaktualizowany/odświeżony motyw ikon Faenza z wieloma opcjami kolorów</pl>
   <pt_BR>Tema de ícones ao estilo Faenza atualizado com muitas opções de cores</pt_BR>
   <pt>Tema de ícones ao estilo Faenza com muitas opções de cores, actualizado/refrescado</pt>
   <ro>an updated/refreshed Faenza-ish icon theme with many colour choices</ro>
   <ru>Обновленная тема в стиле Faenza с большим выбором цветов</ru>
   <sk>an updated/refreshed Faenza-ish icon theme with many colour choices</sk>
   <sl>Posodboljena in osvežena Faenzajevska predloga ikon z mnogobarvnim izborom</sl>
   <sq>an updated/refreshed Faenza-ish icon theme with many colour choices</sq>
   <sr>an updated/refreshed Faenza-ish icon theme with many colour choices</sr>
   <sv>ett uppdaterat/förbättrat Faenza-aktigt ikontema med många färgval</sv>
   <th>an updated/refreshed Faenza-ish icon theme with many colour choices</th>
   <tr>birçok renk seçeneğiyle güncellenmiş / yenilenmiş bir Faenza-ish simge teması</tr>
   <uk>оновлена тема піктограм Faenza з великим вибором кольорів</uk>
   <vi>an updated/refreshed Faenza-ish icon theme with many colour choices</vi>
   <zh_CN>an updated/refreshed Faenza-ish icon theme with many colour choices</zh_CN>
   <zh_HK>an updated/refreshed Faenza-ish icon theme with many colour choices</zh_HK>
   <zh_TW>an updated/refreshed Faenza-ish icon theme with many colour choices</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
obsidian-icon-theme
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
obsidian-icon-theme
</uninstall_package_names>
</app>
